Module slice

Module slice 

Variable-length slice APIs for bitwise Hamming distance.

Use this module when vector sizes are determined at runtime. When the size is known at compile time, prefer the array module for better performance (see Choosing an API).

Functions

batch
Compute Hamming distance from one source slice to many target slices (one-to-many).
distance
Compute the bitwise Hamming distance between two byte slices.